import 'dart:async';
import 'dart:convert';
import 'dart:io';

import '../models/config-object.model.dart';
import 'package:path/path.dart' as path_module;

typedef ConvertJsonToTypes<T> = FutureOr<T> Function(Map<String, dynamic>);

class ReadJsonAndConvert<T> {
  final String path;
  final String fileName;
  final ConvertJsonToTypes<T> converter;

  const ReadJsonAndConvert({
    required this.path,
    required this.fileName,
    required this.converter,
  });

  FutureOr<T> call() async {
    final realFilePath = path_module
        .normalize(path_module.join(path.trim(), fileName.trim()))
        .trim();

    final Map<String, dynamic> json =
        jsonDecode(File(realFilePath).readAsStringSync());
    return converter(json);
  }
}

// ignore: non_constant_identifier_names
// ignore: prefer_function_declarations_over_variables, non_constant_identifier_names
final ConvertJsonToTypes<ConfigObjectModel> CONVERTER_JSON_TO_CONFIG_OBJECT =
    (Map<String, dynamic> data) async {
  return ConfigObjectModel.fromJson(data);
};
